@@ -26,9 +26,9 @@ class WebRtcConfAuth
 		$s = self::getPasswordStatus($conference, $username, $password);
 
 		if($s == "participant"){
-			$user['role'] = "participant";//ERole::PARTICIPANT;
+			$user['role'] = ERole::PARTICIPANT;
 		} elseif ($s == "moderator"){
-			$user['role'] = "moderator";//ERole::CONFERENCE;
+			$user['role'] = ERole::CONFERENCE;
 		}
 		else{
 			$user['error'] = $s;
